"use strict";
var bcrypt = require('bcryptjs');
exports.ServerSalt = '';
exports.ClientSalt = '';
function SetClientSalt(salt) {
    exports.ClientSalt = salt;
    validClientSalt();
}
exports.SetClientSalt = SetClientSalt;
function SetServerSalt(salt) {
    exports.ServerSalt = salt;
    validServerSalt();
}
exports.SetServerSalt = SetServerSalt;
function isValidSalt(salt) {
    return !(!salt || salt === '');
}
function validServerSalt() {
    var valid = isValidSalt(exports.ServerSalt);
    if (valid)
        notifyServerSaltWatchers();
    return valid;
}
function validClientSalt() {
    var valid = isValidSalt(exports.ClientSalt);
    if (valid)
        notifyClientSaltWatchers();
    return valid;
}
function validSalts() {
    return validServerSalt() && validClientSalt();
}
var validServerSaltCbList = [];
var validClientSaltCbList = [];
function notifyServerSaltWatchers() {
    if (validServerSaltCbList.length === 0)
        return;
    var temp = validServerSaltCbList;
    validServerSaltCbList = [];
    for (var i = 0; i < temp.length; ++i) {
        temp[i]();
    }
}
function notifyClientSaltWatchers() {
    if (validClientSaltCbList.length === 0)
        return;
    var temp = validClientSaltCbList;
    validClientSaltCbList = [];
    for (var i = 0; i < temp.length; ++i) {
        temp[i]();
    }
}
function addValidServerSaltListener(pro) {
    validServerSaltCbList.push(pro);
}
function addValidClientSaltListener(pro) {
    validClientSaltCbList.push(pro);
}
function UpdateSalts() {
    return new Promise(function (resolve, reject) {
        var done = false;
        function checkDone() {
            if (done) {
                return resolve();
            }
            done = true;
        }
        GenerateSalt().then(function (salt) {
            SetServerSalt(salt);
            checkDone();
        }, function (error) { return reject(error); });
        GenerateSalt().then(function (salt) {
            SetClientSalt(salt);
            checkDone();
        }, function (error) { return reject(error); });
    });
}
exports.UpdateSalts = UpdateSalts;
function GenerateSalt() {
    return new Promise(function (resolve, reject) {
        bcrypt.genSalt().then(function (salt) { return resolve(salt); }, function (error) { return reject(error); });
    });
}
exports.GenerateSalt = GenerateSalt;
function HashString(value, salt) {
    return new Promise(function (resolve, reject) {
        var done = function () {
            bcrypt.hash(value, salt).then(function (result) { return resolve(result); }, function (error) { return reject(error); });
        };
        if (isValidSalt(salt))
            done();
        else {
            reject('Not a valid salt.');
        }
    });
}
exports.HashString = HashString;
function HashStringServer(value) {
    if (validServerSalt())
        return HashString(value, exports.ServerSalt);
    return new Promise(function (resolve, reject) {
        var callBack = function () {
            HashString(value, exports.ServerSalt).then(resolve, reject);
        };
        addValidServerSaltListener(callBack);
    });
}
exports.HashStringServer = HashStringServer;
function HashStringClient(value) {
    if (validClientSalt())
        return HashString(value, exports.ClientSalt);
    return new Promise(function (resolve, reject) {
        var callBack = function () {
            HashString(value, exports.ClientSalt).then(resolve, reject);
        };
        addValidClientSaltListener(callBack);
    });
}
exports.HashStringClient = HashStringClient;
function HashStringSync(value, salt) {
    return bcrypt.hashSync(value, salt);
}
exports.HashStringSync = HashStringSync;
//# sourceMappingURL=index.js.map